Module: Faraday::DigestAuth::Connection
- Defined in:
- lib/faraday/digestauth/connection.rb
Overview
Connection methods
Instance Method Summary collapse
-
#digest_auth(user, password) ⇒ Object
Public: Adds the digest auth middleware at the top and sets the user and password.
Instance Method Details
#digest_auth(user, password) ⇒ Object
Public: Adds the digest auth middleware at the top and sets the user and password.
user - A String with the user. password - A String with the password.
13 14 15 |
# File 'lib/faraday/digestauth/connection.rb', line 13 def digest_auth(user, password) builder.insert(0, Faraday::Request::DigestAuth, user, password) end |